@@ -68,13 +68,22 @@ class LambdaDestination(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-logs-destinations.LambdaDestination",
 ):
-    '''Use a Lamda Function as the destination for a log subscription.'''
+    '''Use a Lambda Function as the destination for a log subscription.'''
+
+    def __init__(
+        self,
+        fn: aws_cdk.aws_lambda.IFunction,
+        *,
+        add_permissions: typing.Optional[builtins.bool] = None,
+    ) -> None:
+        '''LambdaDestinationOptions.
 
-    def __init__(self, fn: aws_cdk.aws_lambda.IFunction) -> None:
-        '''
         :param fn: -
+        :param add_permissions: Whether or not to add Lambda Permissions. Default: true
         '''
-        jsii.create(LambdaDestination, self, [fn])
+        options = LambdaDestinationOptions(add_permissions=add_permissions)
+
+        jsii.create(LambdaDestination, self, [fn, options])
 
     @jsii.member(jsii_name="bind")
     def bind(
@@ -97,9 +106,50 @@ class LambdaDestination(
         return typing.cast(aws_cdk.aws_logs.LogSubscriptionDestinationConfig, jsii.invoke(self, "bind", [scope, log_group]))
 
 
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-logs-destinations.LambdaDestinationOptions",
+    jsii_struct_bases=[],
+    name_mapping={"add_permissions": "addPermissions"},
+)
+class LambdaDestinationOptions:
+    def __init__(
+        self,
+        *,
+        add_permissions: typing.Optional[builtins.bool] = None,
+    ) -> None:
+        '''Options that may be provided to LambdaDestination.
+
+        :param add_permissions: Whether or not to add Lambda Permissions. Default: true
+        '''
+        self._values: typing.Dict[str, typing.Any] = {}
+        if add_permissions is not None:
+            self._values["add_permissions"] = add_permissions
+
+    @builtins.property
+    def add_permissions(self) -> typing.Optional[builtins.bool]:
+        '''Whether or not to add Lambda Permissions.
+
+        :default: true
+        '''
+        result = self._values.get("add_permissions")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "LambdaDestinationOptions(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 __all__ = [
     "KinesisDestination",
     "LambdaDestination",
+    "LambdaDestinationOptions",
 ]
 
 publication.publish()
